@@ -3,8 +3,7 @@
 
 from rdflib import URIRef
 import i18n
-from click import UsageError
-import six
+from .utils import auto_encode
 
 
 def create_triple(s=None, p=None, o=None):
@@ -73,8 +72,8 @@ def validate_class_partition(graph):
         URIRef('http://rdfs.org/ns/void#entities'),
     ]
 
-    for subject, predicates in zip(class_subjects, class_predicates):
-        missing_triples = [create_triple(s=subject, p=rp) for rp in required_predicates if rp not in predicates]
+    for predicates in class_predicates:
+        missing_triples = [create_triple(p=rp) for rp in required_predicates if rp not in predicates]
         error_triples.extend(missing_triples)
 
     return error_triples
@@ -93,8 +92,8 @@ def validate_property_partition(graph):
         URIRef('http://rdfs.org/ns/void#triples'),
     ]
 
-    for subject, predicates in zip(property_subjects, property_predicates):
-        missing_triples = [create_triple(s=subject, p=rp) for rp in required_predicates if rp not in predicates]
+    for predicates in property_predicates:
+        missing_triples = [create_triple(p=rp) for rp in required_predicates if rp not in predicates]
         error_triples.extend(missing_triples)
 
     return error_triples
@@ -103,14 +102,15 @@ def validate_property_partition(graph):
 class GraphValidationError(Exception):
     pass
 
+
 def validate_graph(graph):
 
     errors = []
     errors.extend([error_message('metadata', t) for t in validate_meta_data(graph)])
 
     if 0 < len(errors):
-        message = 'Validation failed.\n' + '\n'.join(['Cause: ' + e for e in errors])
-        raise GraphValidationError(message)
+        message = 'Validation failed.\n' + '\n'.join(['Reason: ' + e for e in errors])
+        raise GraphValidationError(auto_encode(message))
 
     warns = []
     warns.extend([error_message('ClassPartition', t) for t in validate_class_partition(graph)])
@@ -118,4 +118,4 @@ def validate_graph(graph):
 
     if 0 < len(warns):
         message = '\n'.join(['Warn: ' + w for w in warns])
-        print(message.encode('utf-8') if six.PY2 else message)
+        print(auto_encode(message))
